# Generated by Django 5.0.9 on 2024-11-04 00:18

import django.db.models.deletion
import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ipam', '0070_vlangroup_vlan_id_ranges'),
        ('netbox_rpki', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='certificate',
            name='auto_renews',
            field=models.BooleanField(default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='organization',
            name='ext_url',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AddField(
            model_name='organization',
            name='parent_rir',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='rpki_certs', to='ipam.rir'),
        ),
        migrations.AddField(
            model_name='roa',
            name='auto_renews',
            field=models.BooleanField(default=''),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='certificate',
            name='ca_repository',
            field=models.CharField(blank=True),
        ),
        migrations.AlterField(
            model_name='certificate',
            name='issuer',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AlterField(
            model_name='certificate',
            name='private_key',
            field=models.CharField(blank=True),
        ),
        migrations.AlterField(
            model_name='certificate',
            name='public_key',
            field=models.CharField(blank=True),
        ),
        migrations.AlterField(
            model_name='certificate',
            name='publication_url',
            field=models.CharField(blank=True),
        ),
        migrations.AlterField(
            model_name='certificate',
            name='serial',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AlterField(
            model_name='certificate',
            name='subject',
            field=models.CharField(blank=True, max_length=200),
        ),
        migrations.AlterField(
            model_name='certificate',
            name='valid_from',
            field=models.DateField(blank=True),
        ),
        migrations.AlterField(
            model_name='certificate',
            name='valid_to',
            field=models.DateField(blank=True),
        ),
        migrations.AlterField(
            model_name='roa',
            name='valid_from',
            field=models.DateField(blank=True),
        ),
        migrations.AlterField(
            model_name='roa',
            name='valid_to',
            field=models.DateField(blank=True),
        ),
    ]
